<?php
/*
Plugin Name: Tymber Lite
Plugin URI: http://tymber.io/
description: This is a supporter plugin for Tymber eCommerce configuration
Version: 0.0.4
Author: Team Tymber
Author URI: http://tymber.io/
License: GPL2
*/

require 'plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
    'https://app.tymber.me/wp-plugins/tymber-v2-lite/plugin.json',
    __FILE__, //Full path to the main plugin file or functions.php.
    'tymber-v2-lite'
);
if ( ! class_exists( 'TYMBER_V2_LITE' ) ) {
		
	/**
	 * Localisation
	 **/
	load_plugin_textdomain( 'tymber_v2_lite_lite', false, dirname( plugin_basename( __FILE__ ) ) . '/' );

	class TYMBER_V2_LITE {
		
		public function __construct() {

			if( !get_option('tv2_lite_disable_relative_url') ){
				function tv2_callback_relative_url($buffer) {
					// Replace normal URLs
					$home_url = esc_url(home_url('/'));
					$home_url_relative = wp_make_link_relative($home_url);
				
					// Replace URLs in inline scripts
					$home_url_escaped = str_replace('/', '\/', $home_url);
					$home_url_escaped_relative = str_replace('/', '\/', $home_url_relative);
					
					$buffer = str_replace($home_url, $home_url_relative, $buffer);
					$buffer = str_replace($home_url_escaped, $home_url_escaped_relative, $buffer);
					
					return $buffer;
				}
				
				function tv2_buffer_start_relative_url() { ob_start('tv2_callback_relative_url'); }
				function tv2_buffer_end_relative_url() { @ob_end_flush(); }
				
				if(get_option('tv2_lite_disable_relative_url_on_dashboard')){
					if( !is_admin() && ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) ){
						// http://codex.wordpress.org/Plugin_API/Action_Reference
						add_action('registered_taxonomy', 'tv2_buffer_start_relative_url');
						add_action('shutdown', 'tv2_buffer_end_relative_url');
					}
				}
				else{
					// http://codex.wordpress.org/Plugin_API/Action_Reference
					add_action('registered_taxonomy', 'tv2_buffer_start_relative_url');
					add_action('shutdown', 'tv2_buffer_end_relative_url');
				}
			}

			
			// indicates we are running the admin
			if ( is_admin() ) {					
				include( 'tymber-v2-lite-settings.php' );
			}
				

			if( !get_option('tv2_lite_disable_storemenu') ){
				function tv2_lite_add_custom_headers() {
					add_filter( 'rest_pre_serve_request', function( $value ) {
						header( 'Access-Control-Allow-Headers: Authorization, X-WP-Nonce,Content-Type, X-Requested-With');
						header( 'Access-Control-Allow-Origin: *' );
						header( 'Access-Control-Allow-Methods: GET' );
						header( 'Access-Control-Allow-Credentials: true' );

						return $value;
					} );
				}
				add_action( 'rest_api_init', 'tv2_lite_add_custom_headers', 15 );

				//https://wordpress.stackexchange.com/questions/209381/get-wp-navigation-menu-from-rest-api-v2
				function tv2_lite_get_sidebarmenu() {
					# Change 'menu' to your own navigation slug.
					return wp_get_nav_menu_items('store');
				}

				add_action( 'rest_api_init', function () {
					register_rest_route( 'sidebar-nav', '/store/', array(
						'methods' => 'GET',
						'callback' => 'tv2_lite_get_sidebarmenu',
					) );
				} );
				//https://developer.wordpress.org/reference/functions/wp_create_nav_menu/
				$sidebarmenu_name   = 'store';
				$sidebarmenu_exists = wp_get_nav_menu_object( $sidebarmenu_name );
				if ( ! $sidebarmenu_exists ) {
					$sidebarmenu_id = wp_create_nav_menu($sidebarmenu_name);
				}
			}
			
			if( !get_option('tv2_lite_enable_wild_url_guesses') ){
				function tv2_lite_remove_redirect_guess_404_permalink( $redirect_url ) {
					if ( is_404() && !isset($_GET['p']) )
						return false;
					return $redirect_url;
				}				
				add_filter( 'redirect_canonical', 'tv2_lite_remove_redirect_guess_404_permalink' );
			}

			if( !get_option('tv2_lite_turnoff_mainsite_redirection') ){
				add_action( 'wp', 'tv2_lite_redirect_to_main_domain' );
				function tv2_lite_redirect_to_main_domain() {
					if ( !is_user_logged_in() && $GLOBALS['pagenow'] !== 'wp-login.php' && !is_admin() && is_page()  ) {
						// echo "<pre><code>";
						// print_r( $_SERVER);
						// echo "</code></pre>";
						$first_two_letters =  $_SERVER['REQUEST_URI'][0].$_SERVER['REQUEST_URI'][1];
						// echo $first_two_letters ."<hr>";
						// echo substr($_SERVER['REQUEST_URI'], -1);
						if( $_SERVER['REQUEST_URI'] =='' || $_SERVER['REQUEST_URI'] =='/' || substr($_SERVER['REQUEST_URI'], -1) == '/' || $first_two_letters == '/?' ){
							
						}
						else{
							if( $_SERVER['QUERY_STRING'] !='' ){				
								$path = str_replace("?".$_SERVER['QUERY_STRING'],"",$_SERVER['REQUEST_URI']);
								$path = rtrim($path,"/"). '/'."?".$_SERVER['QUERY_STRING'];
								if( $path != $_SERVER['REQUEST_URI'] ){									
									wp_redirect(  $path );
									exit();
									die;
								}
							}
							else
							{				
								$path = $_SERVER['REQUEST_URI'];
								$path = rtrim($path,"/"). '/';
								wp_redirect(  $path );
								exit();
								die;
							}
							
						}
					}
				}
			}


			//don't load on divi builder
			if( !isset($_GET['et_fb'])){

			}
			
		}
	}

	// finally instantiate our plugin class and add it to the set of globals
	$GLOBALS['tymber_v2_lite'] = new TYMBER_V2_LITE();
}